@@ -11,21 +11,21 @@ test_that("'get_col_types' argument gives character if 'data' a dataframe or mat
 })
 
 test_that("'get_col_types' argument gives character if 'data' a dataframe or matrix", {
-  d <- data.frame(Model = c('Mazda', 'Pegeout', 'Honda Fit', 'Honda CRV'))
+  d <- data.frame(Model = c('Mazda', 'Pegeout', 'Honda Fit', 'Honda CRV'), stringsAsFactors = TRUE)
 
   testthat::expect_equal(get_col_types(data=d), c("dropdown"))
 })
 
 test_that("'get_col_types' argument gives character if 'data' a dataframe or matrix", {
   d <- data.frame(Model = c('Mazda', 'Pegeout', 'Honda Fit', 'Honda CRV'),
-                   Availability = c(TRUE, FALSE, TRUE, TRUE))
+                   Availability = c(TRUE, FALSE, TRUE, TRUE), stringsAsFactors = TRUE)
   testthat::expect_equal(get_col_types(data=d), c("dropdown", "checkbox"))
 })
 
 test_that("'get_col_types' argument gives character if 'data' a dataframe or matrix", {
   d <- data.frame(Model = c('Mazda', 'Pegeout', 'Honda Fit', 'Honda CRV'),
                     Date=c(as.Date('2006-01-01'), as.Date('2005-01-01'),
-                    as.Date('2004-01-01'), as.Date('2003-01-01' )))
+                    as.Date('2004-01-01'), as.Date('2003-01-01' )), stringsAsFactors = TRUE)
 
   testthat::expect_equal(get_col_types(data=d), c("dropdown", "calendar"))
 })
@@ -53,4 +53,4 @@ test_that("'get_col_types' argument gives error if 'data' not a dataframe or mat
 test_that("'get_col_types' argument gives character if 'data' a dataframe or matrix", {
   d <- matrix( c(as.double(1), as.double(2.5)), ncol=1)
   testthat::expect_equal(get_col_types(data=d), c("numeric"))
-})
\ No newline at end of file
+})
